@@ -7,6 +7,7 @@ except ImportError:
     xrange = range  # python 3
 
 from .._mesh import MeshBase
+from ..util import coordinates_hash
 from ..triangulation import earcut
 
 from .pointvector import Point2D, Vector2D
@@ -473,6 +474,27 @@ class Mesh2D(MeshBase):
         new_mesh._face_areas = _new_f_area
         return new_mesh
 
+    def apply_point_map(self, point_map, tolerance):
+        """Apply a mapping of points from this mesh's vertices to a new mesh.
+
+        Args:
+            point_map: A dictionary with strings of coordinates as keys and Point3Ds
+                as values. The keys refer to points within this Mesh3D to be
+                moved to the new positions provided by the corresponding value.
+                Correct keys can be generated by using the coordinates_hash_3d
+                function on the vertices of this Mesh, found under the util module.
+            tolerance: The minimum difference between point values that is
+                considered meaningful. This is used as input to the
+                coordinates_hash_3d function to generate correct hashes.
+        """
+        _new_verts = []
+        for ev in self.vertices:
+            try:
+                _new_verts.append(point_map[coordinates_hash(ev, tolerance)])
+            except KeyError:  # a point that is not in the map
+                _new_verts.append(ev)
+        return Mesh2D(_new_verts, self.faces, self.colors)
+
     def rotate(self, angle, origin):
         """Get a mesh that is rotated counterclockwise by a certain angle.
 
