@@ -3,6 +3,7 @@
 from __future__ import division
 
 from .._mesh import MeshBase
+from ..util import coordinates_hash_3d
 from ..geometry2d.mesh import Mesh2D
 from .pointvector import Point3D, Vector3D
 from .line import LineSegment3D
@@ -377,6 +378,45 @@ class Mesh3D(MeshBase):
         new_mesh._face_areas = _new_f_area
         return new_mesh
 
+    def snap_to_points(self, points, distance):
+        """Get a version of this mesh that is snapped to a set of points.
+
+        Args:
+            points: A list of Point3D to which the vertices of this mesh will be snapped.
+            distance: The distance at which a mesh vertex close to a point will
+                be snapped to it.
+        """
+        _new_verts = []
+        for ev in self.vertices:
+            dists = [ev.distance_to_point(pt) for pt in points]
+            sort_pt = sorted(zip(dists, points), key=lambda pair: pair[0])
+            if sort_pt[0][0] <= distance:
+                _new_verts.append(sort_pt[0][1])
+            else:
+                _new_verts.append(ev)
+        return Mesh3D(_new_verts, self.faces, self.colors)
+
+    def apply_point_map(self, point_map, tolerance):
+        """Apply a mapping of points from this mesh's vertices to a new mesh.
+
+        Args:
+            point_map: A dictionary with strings of coordinates as keys and Point3Ds
+                as values. The keys refer to points within this Mesh3D to be
+                moved to the new positions provided by the corresponding value.
+                Correct keys can be generated by using the coordinates_hash_3d
+                function on the vertices of this Mesh, found under the util module.
+            tolerance: The minimum difference between point values that is
+                considered meaningful. This is used as input to the
+                coordinates_hash_3d function to generate correct hashes.
+        """
+        _new_verts = []
+        for ev in self.vertices:
+            try:
+                _new_verts.append(point_map[coordinates_hash_3d(ev, tolerance)])
+            except KeyError:  # a point that is not in the map
+                _new_verts.append(ev)
+        return Mesh3D(_new_verts, self.faces, self.colors)
+
     def rotate(self, axis, angle, origin):
         """Rotate a mesh by a certain angle around an axis and origin.
 
